=======
History
=======

1.1.10 (2020-10-22)
-------------------

* multiaxis_graph_plotter title generation bug fixed
* Checklist feature removed and is no longer supported
* arduino_flight_data folder renamed to csv_flight_data NOTE: This will require a new folder structure to be created or it will cause errors by searching for the old folder names


1.1.9 (2020-05-20)
------------------

* Options added in log_analysis.autoflpy for including METAR data and running log_to_xlsx to generate xlsx files of the data
* Runway and weather data is now written as a table tor ease of viewing


1.1.8 (2020-05-07)
------------------

* Documentation updated to include examples of the backplt_map function
* Improvements made to the backplt_map function for isolated use


1.1.7 (2020-04-30)
------------------

* multiaxis_graph_plotter bug where the data was plotted on the wrong axis fixed
* backplt_map improved so that the z_var data always corresponds to the correct gps data (linked via time)
* flight_numbers can now be decimals for recording sub-flight numbers


1.1.6 (2020-04-24)
------------------

* backplt_map in plotting.py now returns a figure object for further customisation


1.1.5 (2020-04-17)
------------------

* backplt_map in plotting.py upgraded for stand alone use


1.1.4 (2020-03-23)
------------------

* Documentation updated
* Unit tests updated


1.1.3 (2020-03-10)
------------------

* METAR bug fixed


1.1.2 (2020-03-10)
------------------

* Multi-flight comparison functionality added


1.1.1 (2020-02-19)
------------------

* Custom runway data functionality added

1.1.0 (2020-02-19)
------------------

* Code modularised
* Unit tests updated

1.0.18 (2020-01-31)
-------------------

* Bug fixes

1.0.17 (2020-01-31)
-------------------

* Automatic take-off detection based on GPS altitude data added
* Requirements updated

1.0.16 (2020-01-28)
-------------------

* Custom weather data functionality added
* Conditional colouring functionality added to the map plot
* Functionality to add time markers across all plots simultaneously

1.0.15 (2020-01-23)
-------------------

* Checklist name bug fixed

1.0.14 (2020-01-22)
-------------------

* Documentation updated
* Addition of a function to mark the arm and disarm points in the flight
* Addition of a function to add custom graph titles to the generated figures
* Preliminary take-off plotting function added. This can onlt be accessed manually
* Added the possibility to export the generated flight log from Jupyter to html without any code showing
* Repaired the checklist function

1.0.13 (2020-01-14)
-------------------

* Added the ability to change the map line colour through a separate variable
* Previous demonstration data replaced with SITL generated data

1.0.12 (2020-01-13)
-------------------

* Map formatting improved
* Documentation updated with images and examples

1.0.11 (2020-01-09)
-------------------

* Improved code formatting
* Added improved map backplotting for greater speed

1.0.10 (2020-01-07)
-------------------

* Removed warnings in the jupyter notebook
* Improved the map backplotting function
* Renamed graph_function to graph_plotter

1.0.9 (2020-01-06)
------------------

* Repaired map backplotting functions
* Added scale factor to map

1.0.8 (2019-12-12)
------------------

* Upgraded from .xls to .xlsx

1.0.7 (2019-12-11)
------------------

* Figure sizes changed

1.0.6 (2019-12-11)
------------------

* Fixed minor issues
* Added better map package installation instructions

1.0.5 (2019-12-10)
------------------

* Added data compression for faster notebook running

1.0.4 (2019-12-05)
------------------

* Added backplotted map for latitude and longitude data

1.0.3 (2019-11-28)
------------------

* Compatibility extended to Python 3.5 and 3.8
* Improved the default template and plotting functions

1.0.2 (2019-11-26)
------------------

* Compatibility for multiple operating systems improved

1.0.1 (2019-11-26)
------------------

* Metar module issue fixed

1.0.0 (2019-11-25)
------------------

* AutoFLpy v 1.0.0 released

0.2.6 (2019-11-25)
------------------

* Updated Default Template with GPS and autopilot data
* Imporved unit testing

0.2.5 (2019-11-14)
------------------

* Checklist issues resolved
* Unittests expanded

0.2.4 (2019-11-14)
------------------

* Documentation updated

0.2.3 (2019-11-12)
------------------

* Changed autoflpy.py to log_analysis.py


0.2.2 (2019-11-12)
------------------

* Default storage directory bug fixed

0.2.1 (2019-11-12)
------------------

* Generated the input file into the generated folder structure
* Added example data for first time running

0.2.0 (2019-11-08)
------------------

* Fixed path issues in template

0.1.4 (2019-11-08)
------------------

* Fixed more directory issues

0.1.3 (2019-11-08)
------------------

* Fixed directory issues

0.1.2 (2019-11-08)
------------------

* Reformatted directory and added default user files.

0.1.1 (2019-11-07)
------------------

* Updates and added code. Reformatted directory.

0.1.0 (2019-10-29)
------------------

* First release on PyPI.
